==> org.eclipse.papyrus.uml.diagram.activity.source_2.0.0.201612071107.jar: org/eclipse/papyrus/uml/diagram/activity/edit/part/BaseActivityContentCompartmentEditPart.java <==
/*****************************************************************************
 * Copyright (c) 2011 Atos.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Arthur Daussy (Atos) - Initial API and implementation
 *   Arthur Daussy - 371712 : 372745: [ActivityDiagram] Major refactoring group framework
 *
 *****************************************************************************/
package org.eclipse.papyrus.uml.diagram.activity.edit.part;

import org.eclipse.draw2d.IFigure;
import org.eclipse.gmf.runtime.diagram.ui.figures.ResizableCompartmentFigure;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.gmf.tooling.runtime.linklf.LinkLFShapeCompartmentEditPart;

/**
 * @author adaussy
 *
 */
public class BaseActivityContentCompartmentEditPart extends LinkLFShapeCompartmentEditPart {

	public BaseActivityContentCompartmentEditPart(View view) {
		super(view);
	}

	/**
	 * remove the top border
	 * hide title
	 */
	@Override
	public IFigure createFigure() {
		ResizableCompartmentFigure result = (ResizableCompartmentFigure) super.createFigure();
		result.setTitleVisibility(false);
		// remove the top border
		result.setBorder(null);
		return result;
	}

	/**
	 * Unselectable compartment
	 */
	@Override
	public boolean isSelectable() {
		return false;
	}
}

==> org.eclipse.papyrus.uml.diagram.activity.source_3.0.0.201805210649.jar: org/eclipse/papyrus/uml/diagram/activity/edit/part/BaseActivityContentCompartmentEditPart.java <==
/*****************************************************************************
 * Copyright (c) 2011 Atos.
 *
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Arthur Daussy (Atos) - Initial API and implementation
 *   Arthur Daussy - 371712 : 372745: [ActivityDiagram] Major refactoring group framework
 *
 *****************************************************************************/
package org.eclipse.papyrus.uml.diagram.activity.edit.part;

import org.eclipse.draw2d.IFigure;
import org.eclipse.gmf.runtime.diagram.ui.figures.ResizableCompartmentFigure;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.papyrus.infra.gmfdiag.tooling.runtime.linklf.LinkLFShapeCompartmentEditPart;

/**
 * @author adaussy
 *
 */
public class BaseActivityContentCompartmentEditPart extends LinkLFShapeCompartmentEditPart {

	public BaseActivityContentCompartmentEditPart(View view) {
		super(view);
	}

	/**
	 * remove the top border
	 * hide title
	 */
	@Override
	public IFigure createFigure() {
		ResizableCompartmentFigure result = (ResizableCompartmentFigure) super.createFigure();
		result.setTitleVisibility(false);
		// remove the top border
		result.setBorder(null);
		return result;
	}

	/**
	 * Unselectable compartment
	 */
	@Override
	public boolean isSelectable() {
		return false;
	}
}
